---
title: Matrix-valued functions
---

::: klax.nn.Matrix
    options:
        members:
            - __init__
            - __call__

---

::: klax.nn.ConstantMatrix
    options:
        members:
            - __init__
            - __call__

---

::: klax.nn.SkewSymmetricMatrix
    options:
        members:
            - __init__
            - __call__

---

::: klax.nn.ConstantSkewSymmetricMatrix
    options:
        members:
            - __init__
            - __call__

---

::: klax.nn.SPDMatrix
    options:
        members:
            - __init__
            - __call__

---

::: klax.nn.ConstantSPDMatrix
    options:
        members:
            - __init__
            - __call__